@@ -96,9 +96,8 @@ cliques <- function(graph, min=NULL, max=NULL) {
     max <- 0
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_cliques", graph, as.numeric(min), as.numeric(max),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_cliques, graph, as.numeric(min), as.numeric(max))
   res <- lapply(res, function(x) x+1)
 
   if (igraph_opt("return.vs.es")) {
@@ -115,9 +114,8 @@ largest_cliques <- function(graph) {
     stop("Not a graph object")
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_largest_cliques", graph,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_largest_cliques, graph)
   res <- lapply(res, function(x) x+1)
 
   if (igraph_opt("return.vs.es")) {
@@ -163,19 +161,18 @@ max_cliques <- function(graph, min=NULL, max=NULL,
     } else {
       tmpfile <- FALSE
     }
-    on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-    res <- .Call("R_igraph_maximal_cliques_file", graph, subset, file,
-                 as.numeric(min), as.numeric(max), PACKAGE="igraph")
+    on.exit( .Call(C_R_igraph_finalizer) )
+    res <- .Call(C_R_igraph_maximal_cliques_file, graph, subset, file,
+                 as.numeric(min), as.numeric(max))
     if (tmpfile) {
       buffer <- read.graph.toraw(file)
       write.graph.fromraw(buffer, origfile)
     }
     invisible(NULL)
   } else { 
-    on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-    res <- .Call("R_igraph_maximal_cliques", graph, subset,
-                 as.numeric(min), as.numeric(max),
-                 PACKAGE="igraph")
+    on.exit( .Call(C_R_igraph_finalizer) )
+    res <- .Call(C_R_igraph_maximal_cliques, graph, subset,
+                 as.numeric(min), as.numeric(max))
     res <- lapply(res, function(x) x+1)
 
     if (igraph_opt("return.vs.es")) {
@@ -202,10 +199,9 @@ count_max_cliques <- function(graph, min=NULL, max=NULL,
     subset <- as.integer(as.igraph.vs(graph, subset)-1)
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
+  on.exit( .Call(C_R_igraph_finalizer) )
   # Function call
-  res <- .Call("R_igraph_maximal_cliques_count", graph, subset, min, max,
-               PACKAGE="igraph")
+  res <- .Call(C_R_igraph_maximal_cliques_count, graph, subset, min, max)
 
   res
 }
@@ -217,9 +213,8 @@ clique_num <- function(graph) {
     stop("Not a graph object");
   }
   
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_clique_number", graph,
-        PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  .Call(C_R_igraph_clique_number, graph)
 }
 
 
@@ -304,10 +299,9 @@ ivs <- function(graph, min=NULL, max=NULL) {
     max <- 0
   }
   
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_independent_vertex_sets", graph, as.numeric(min),
-               as.numeric(max),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_independent_vertex_sets, graph, as.numeric(min),
+               as.numeric(max))
   res <- lapply(res, function(x) x+1)
 
   if (igraph_opt("return.vs.es")) {
@@ -324,9 +318,8 @@ largest_ivs <- function(graph) {
     stop("Not a graph object");
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_largest_independent_vertex_sets", graph,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_largest_independent_vertex_sets, graph)
   res <- lapply(res, function(x) x+1)
 
   if (igraph_opt("return.vs.es")) {
@@ -343,9 +336,8 @@ maximal_ivs <- function(graph) {
     stop("Not a graph object");
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_maximal_independent_vertex_sets", graph,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_maximal_independent_vertex_sets, graph)
   res <- lapply(res, function(x) x+1)
 
   if (igraph_opt("return.vs.es")) {
@@ -362,7 +354,6 @@ ivs_size <- function(graph) {
     stop("Not a graph object");
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_independence_number", graph,
-        PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  .Call(C_R_igraph_independence_number, graph)
 }
