@@ -381,6 +381,7 @@ void graph::read_parms ( char *parms_file )
 
 void graph::init_parms ( int rand_seed, float edge_cut, float real_parm )
 {
+        IGRAPH_UNUSED(rand_seed);
 
 	// first we translate edge_cut the former tcl sliding scale
 	//CUT_END = cut_length_end = 39000.0 * (1.0 - edge_cut) + 1000.0;
@@ -890,8 +891,8 @@ void graph::update_nodes ( )
 		// compute node list for next update
 		for ( unsigned int j = 0; j < node_indices.size(); j++ )
 		  node_indices [j] += num_procs;
-		
-		while ( node_indices [ node_indices.size()-1] >= num_nodes )
+	
+		while ( !node_indices.empty() && node_indices.back() >= num_nodes )
 		  node_indices.pop_back ( );
 			
 	}
